## 0.0.10 - 2022-02-17

### Added

- [#192](https://github.com/edgarrmondragon/citric/pull/192) Implement `copy_survey` in client
- [#190](https://github.com/edgarrmondragon/citric/pull/190) Implement `import_group` in client
- [#196](https://github.com/edgarrmondragon/citric/pull/196) Implement `list_groups` in client
- [#194](https://github.com/edgarrmondragon/citric/pull/194) Implement `delete_group` in client
- [#207](https://github.com/edgarrmondragon/citric/pull/207) Implement `add_language` in client
- [#210](https://github.com/edgarrmondragon/citric/pull/210) Implement `add_survey` in client
- [#231](https://github.com/edgarrmondragon/citric/pull/231) Implement `get_`\*\_properties in client
- [#240](https://github.com/edgarrmondragon/citric/pull/237) Implement `export_statistics`, `save_statistics` and `save_responses` in client
- [#241](https://github.com/edgarrmondragon/citric/pull/241) Implement `get_summary` in client
- [#240](https://github.com/edgarrmondragon/citric/pull/240) Implement `export_timeline` in client

### Fixed

- [#215](https://github.com/edgarrmondragon/citric/pull/215) Address code smells and other issues
